///File : App.cpp
//------------------------------------------------------------------------------
/*
    This file is part of LCDnurse.

    LCDnurse is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    LCDnurse is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with LCDnurse.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "App.hpp"
//------------------------------------------------------------------------------
IMPLEMENT_APP(App)

#ifdef __WXMAC__
    #include <ApplicationServices/ApplicationServices.h>
#endif
//------------------------------------------------------------------------------
bool App::OnInit()
{
    #ifdef __WXMAC__
    ProcessSerialNumber PSN;
    GetCurrentProcess(&PSN);
    TransformProcessType(&PSN,kProcessTransformToForegroundApplication);
    #endif

    // Création du Handler pour les images (permet de les ouvrir)...
    wxInitAllImageHandlers();

    // Gestion de la langue
    // Ajout des préfixes possibles de chemins d'accès aux catalogues
    wxLocale::AddCatalogLookupPathPrefix(wxT("."));
    wxLocale::AddCatalogLookupPathPrefix(wxT(".."));
    wxLocale::AddCatalogLookupPathPrefix(findFile(_T("locale")));
    //wxLocale::AddCatalogLookupPathPrefix(wxStandardPaths().GetDataDir() + _T("/locale"));

    // Mise en place de la langue par défaut du système
    m_locale.Init(wxLANGUAGE_DEFAULT);
    {
       wxLogNull noLog; // Supprime les erreurs si les catalogues n'existent pas
       // Catalogue de l'application
       m_locale.AddCatalog(_T("lcdnurse"));
       // Catalogue de wxWidgets
       m_locale.AddCatalog(_T("wxstd"));
    }

    try
    {
        wxString frameTitle = _T("LCD Nurse");
        #if DEBUG == 1
           frameTitle += _T(" - Debug");
        #endif

        MainFrame *frame = new MainFrame(frameTitle,  wxDefaultPosition, wxDefaultSize, wxDEFAULT_FRAME_STYLE | wxSTAY_ON_TOP);
        frame->ShowFullScreen(true);
        //frame->Maximize(true);
        frame->Show(true);
    }
    catch(const std::exception& e) //Rattrape toutes les exceptions
    {
        wxMessageBox(_("Error : ") + wxString(e.what(), wxConvUTF8), _("Error..."),  wxOK | wxICON_ERROR);
        exit(1);
    }

    return true;
}
